@@ -2,8 +2,8 @@ from nzpyida import IdaDataBase, IdaDataFrame
 
 from nzpyida.ae.install import NZInstall
 
-idadb = IdaDataBase('weather', 'admin', 'password')
+idadb = IdaDataBase('fyre', 'admin', 'password')
 
-nzinstall = NZInstall(idadb, package_name='pandas')
+nzinstall = NZInstall(idadb, package_name='scikit-learn')
 print(nzinstall.getResultCode())
 
